# blow

## Motivation

Load testing a page quickly.

## Installation

```
pip install blow
```

## Usage

```
blow --method get --factor 123 https://example.com
```

## License

This project is licensed under the GPL-3 license.
